@@ -1,6 +1,6 @@
 import argparse
 import logging as log
-import json
+import pyjson5
 import sys
 import importlib
 import time
@@ -41,7 +41,7 @@ def main():
     parser.add_argument('config')
     args = parser.parse_args()
     with open(args.config) as config_file:
-        config = json.load(config_file)
+        config = pyjson5.load(config_file)
 
         if 'sparql' in config:
             endpoint = config['sparql']['endpoint']
