@@ -1,8 +1,10 @@
+from knowledge_mapper.knowledge_base import KnowledgeBase
+
 class DataSource:
     def test(self):
         raise NotImplementedError("Please implement this abstract method.")
     def handle(self, ki, binding_set):
         raise NotImplementedError("Please implement this abstract method.")
-
-    def set_tke_client(self, tke_client):
-        self.tke_client = tke_client
+    
+    def set_knowledge_base(self, kb: KnowledgeBase):
+        self.kb = kb
